def cli():
    """HTML Pull.

    Usage:
      htmlpull xpath [-0] <xpath> [--] [<file> ...]
      htmlpull -h | --help | --version

    Arguments:
      xpath        xpath to select elements
      file         html file, - for stdin

    Options:
      -h --help     Show this screen.
      --version     Show version.
    """
    import docopt
    args = docopt.docopt(cli.__doc__)
    files = args["<file>"]
    xpath = args['<xpath>']
    endl = '\0' if args["-0"] else '\n'
    import sys
    import html5lib
    from lxml import etree
    if not files:
        files.append('-')
    for f in files:
        if f == '-':
            f = sys.stdin.buffer
        else:
            f = open(f, 'rb')

        tree = html5lib.parse(f, "lxml", namespaceHTMLElements=False)

        items = tree.xpath(xpath)

        for item in items:
            if not isinstance(item, str):
                item = html5lib.serialize(item)
            print(item, end=endl)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['htmlpull']

package_data = \
{'': ['*']}

install_requires = \
['docopt>=0.6.2,<0.7.0', 'html5lib>=1.1,<2.0', 'lxml>=4.6.4,<5.0.0']

entry_points = \
{'console_scripts': ['htmlpull = htmlpull.cli:cli']}

setup_kwargs = {
    'name': 'htmlpull',
    'version': '0.3.0',
    'description': '',
    'long_description': None,
    'author': 'Summer',
    'author_email': '30243134+Summertime@users.noreply.github.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
